/*
    Text maid
    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
#ifndef __REPLACE_H__
#define __REPLACE_H__


#include "tmaid.h"


G_BEGIN_DECLS


#define REPLACE_TEXT 16


extern gchar *replace_text[REPLACE_TEXT];   /* ja:置換する文字列 */


/******************************************************************************
*                                                                             *
* ja:置換関数群                                                               *
*                                                                             *
******************************************************************************/
/*  ja:置換
    mode,モード                                                             */
void
replace_operation (gint mode);


G_END_DECLS


#endif /* __REPLACE_H__ */
